@@ -1514,101 +1514,6 @@ _Matrix * _DataSetFilter::HarvestFrequencies (char unit, char atom, bool posSpec
     return theData->HarvestFrequencies (unit,atom, posSpec, copy_seqs, copy_sites, countGaps);
 }
 
-
-/*
- //_______________________________________________________________________
- long    _DataSetFilter::GetVectorCode(long site,long seq)
- {
- if (!symbolVector) return -1;
- long* fi = symbolVector->quickArrayAccess();
- return fi[*fi*site+seq+1];
- }
- //_______________________________________________________________________
- 
- void    _DataSetFilter::ProduceSymbolVector(bool smear)
- {
- // compute the size of the vector cells
- hyFloat cellSize=log((hyFloat)theData->theTT->LengthOfAlphabet())*hyFloat(unitLength)/log(128.0);
- if (cellSize>2.0)
- {
- _String errMsg ("DataSetFilter has more than 32767 states, which is currently unsupported");
- FlagError(errMsg);
- }
- long intCellSize = cellSize>1.0?2:1;
- // now produce the conversion vector
- long sites = theMap.lLength, species= theNodeMap.lLength?theNodeMap.lLength:theData->NoOfSpecies();
- symbolVector = new _SimpleList ();
- checkPointer(symbolVector);
- //  (*symbolVector)<<intCellSize;
- (*symbolVector)<<species;
- // we will now speciate into byte and word size cases
- // the data will be stored column by column
- // if there is a unique code translation, we then store that code in the symbol vector for faster
- // processing during tree pruning business.
- // use a standard convert to frequencies function to check whether a character has a unique convertion
- if (intCellSize==1) // char based storage
- {
- union
- {
- long composite;
- char bytes[sizeof(long)];
- } converterb;
- char byteposition = 0, bytesPerLong = sizeof(long);
- for (long i=0;i<sites;i++)
- {
- for (long j=0; j<species; j++)
- {
- //              if (byteposition==bytesPerLong)
- //              {
- //                  byteposition = 0;
- //                  (*symbolVector)<<converterb.composite;
- //              }
- //              converterb.bytes[byteposition]=(char)Translate2Frequencies((*this)(i,j),nil,smear,false);
- //              byteposition++;
- (*symbolVector)<<Translate2Frequencies((*this)(i,j),nil,smear,false);
- }
- }
- if (byteposition)
- {
- for(long i=sizeof(long)-1;i>=byteposition;i--)
- {
- converterb.bytes[i]=0;
- }
- (*symbolVector)<<converterb.composite;
- }
- 
- }
- else
- {
- union
- {
- long composite;
- short int words[sizeof(long)/2];
- } converterw;
- char wordposition = 0, wordsPerLong = sizeof(long);
- for (long i=0;i<sites;i++)
- {
- for (long j=0; j<species; j++)
- {
- if (wordposition==wordsPerLong)
- {
- wordposition = 0;
- (*symbolVector)<<converterw.composite;
- }
- converterw.words[wordposition]=(char)Translate2Frequencies((*this)(i,j),nil,smear,false);
- }
- }
- if (wordposition)
- {
- for(long i=sizeof(long)/2-1;i>=wordposition;i--)
- {
- converterw.words[i]=0;
- }
- (*symbolVector)<<converterw.composite;
- }
- }
- }*/
-
 //_______________________________________________________________________
 
 long    _DataSetFilter::CorrectCode (long code) const {
