@@ -301,6 +301,8 @@ _String const
         // used to set the progress message displayed to the user
     tolerate_numerical_errors                       ("TOLERATE_NUMERICAL_ERRORS"),
         // if set, numerical errors that would cause termination are instead trated as warnings
+    tolerate_constraint_violation                   ("TOLERATE_CONSTRAINT_VIOLATION"),
+    // if set, numerical errors that would cause termination are instead trated as warnings
     tree_parser_namespace                           ("_TREE_PARSER_NAMESPACE"),
         // if set, numerical errors that would cause termination are instead trated as warnings
     try_numeric_sequence_match                      ("TRY_NUMERIC_SEQUENCE_MATCH"),
