@@ -78,6 +78,10 @@ class _SimpleList:public BaseObj {
         //length constructor
         _SimpleList(unsigned long);
 
+        //length constructor with storage already preallocated somewhere else
+        //e.g. using `alloca`
+        _SimpleList(unsigned long, long* preallocated_storage);
+    
         // stack copy contructor
         _SimpleList(_SimpleList const&,long=0,long=-1);
     
@@ -296,7 +300,7 @@ class _SimpleList:public BaseObj {
          * @param index Which item you want.
          * @return A long
          */
-        inline const long get (long index) const {return list_data [index];}
+        inline long get (long index) const {return list_data [index];}
 
         /**
         * Checks if list is identical to other list
@@ -606,6 +610,8 @@ class _SimpleList:public BaseObj {
         * Request space for a given # of elements 
         */
         void RequestSpace(long);
+    
+        virtual bool is_numeric_list (void) const { return true;}
 
         void Subtract(_SimpleList const &, _SimpleList const&);
 
@@ -670,7 +676,7 @@ class _SimpleList:public BaseObj {
         *
         */
     
-        _SimpleList* CountingSort(long, _SimpleList* = nil);
+        _SimpleList* CountingSort(long, _SimpleList* = nil, bool wantResult = true);
 
         void BubbleSort(void);
         void QuickSort(long, long);
